

class RankData:
    
    def __init__(data):
        pass
    
    def serialize(data, types):
        pass 
    
    def scanContext(data):
        pass
    
    
    def rankData(data):
        pass