import tensorflow as tf #machine learning library 
import numpy as np #tables transformations 
import scipy as sp #doing some equasions 


class ml:
    
    def __init__():
        
        search = tf.feature_column.numeric_column("search")
        result = tf.feature_column.numeric_column("result")
        
        
    
    def train():
        pass
    
    def analyzeData(var1, var2, var3):
        pass