# -*- coding: utf-8 -*- 
from .ranks import RankData
import re
import validators

class sortData:
    
    def __init__(self):
        pass
    
    
    def uniqueWords(text):
        words  = {}
        pass
    
    def addToCategory(word):
        
        categories = {'tech', 'faith', 'jesus', 'christ'}
        RankData.rankData(word)
        
    def sort(text):
        pass

    
        